Retrieves the ID of mother of ego or mothers of vector of egos
Usage
IDmother(idego, d = NULL)
Value
ID of mother. Returns NA if ID of mother is not included in the database
Arguments
idego
ID
d
Name of database. If d is missing, the dataset dLH in the global environment (R workspace) is used.
If no dLH in the global environment, the database dLH distributed with the Families package is used.